# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: quote/mdsquote.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='quote/mdsquote.proto',
  package='mdsquote',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x14quote/mdsquote.proto\x12\x08mdsquote\"\'\n\x06\x42SNode\x12\r\n\x05price\x18\x01 \x01(\x01\x12\x0e\n\x06volume\x18\x02 \x01(\x05\"\xb5\x01\n\x0c\x42\x61seTickData\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\x0c\x12\x0c\n\x04time\x18\x04 \x01(\x03\x12\x17\n\x0fpre_close_price\x18\x05 \x01(\x01\x12\x12\n\nopen_price\x18\x06 \x01(\x01\x12\x12\n\nhigh_price\x18\x07 \x01(\x01\x12\x11\n\tlow_price\x18\x08 \x01(\x01\x12\x12\n\nlast_price\x18\t \x01(\x01\"\xe2\x02\n\rStockTickData\x12$\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x16.mdsquote.BaseTickData\x12\x0e\n\x06volume\x18\x02 \x01(\x01\x12\x10\n\x08turnover\x18\x03 \x01(\x01\x12\x1d\n\x03\x62id\x18\x04 \x03(\x0b\x32\x10.mdsquote.BSNode\x12\x1d\n\x03\x61sk\x18\x05 \x03(\x0b\x32\x10.mdsquote.BSNode\x12\x10\n\x08volmount\x18\x06 \x01(\x05\x12\x10\n\x08volclass\x18\x07 \x01(\x05\x12\x0e\n\x06outvol\x18\x08 \x01(\x05\x12\r\n\x05invol\x18\t \x01(\x05\x12\x0b\n\x03lof\x18\n \x01(\x01\x12\x19\n\x11upper_limit_price\x18\x0b \x01(\x01\x12\x19\n\x11lower_limit_price\x18\x0c \x01(\x01\x12\x0c\n\x04ywzt\x18\r \x01(\t\x12\x18\n\x10\x61\x66ter_market_vol\x18\x0e \x01(\x01\x12\x1d\n\x15\x61\x66ter_market_volmount\x18\x0f \x01(\x01\"\x94\x03\n\x0f\x46uturesTickData\x12$\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x16.mdsquote.BaseTickData\x12\x0e\n\x06volume\x18\x02 \x01(\x01\x12\x10\n\x08turnover\x18\x03 \x01(\x01\x12\x1d\n\x03\x62id\x18\x04 \x03(\x0b\x32\x10.mdsquote.BSNode\x12\x1d\n\x03\x61sk\x18\x05 \x03(\x0b\x32\x10.mdsquote.BSNode\x12\x15\n\ropen_interest\x18\x06 \x01(\x01\x12\x15\n\rpre_set_price\x18\x07 \x01(\x01\x12\x11\n\tset_price\x18\x08 \x01(\x01\x12\x0f\n\x07voclass\x18\t \x01(\x05\x12\x19\n\x11upper_limit_price\x18\n \x01(\x01\x12\x19\n\x11lower_limit_price\x18\x0b \x01(\x01\x12\x19\n\x11pre_open_interest\x18\x0c \x01(\x01\x12\x0e\n\x06\x65xcode\x18\r \x01(\x0c\x12\x11\n\this_hight\x18\x0e \x01(\x01\x12\x0f\n\x07his_low\x18\x0f \x01(\x01\x12\x11\n\tpre_delta\x18\x10 \x01(\x01\x12\x11\n\tcur_delta\x18\x11 \x01(\x01\";\n\x10NotificationTick\x12\'\n\x04tick\x18\x01 \x01(\x0b\x32\x19.mdsquote.FuturesTickData\"\xc9\x02\n\rCffexTickData\x12$\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x16.mdsquote.BaseTickData\x12\x0e\n\x06volume\x18\x02 \x01(\x01\x12\x10\n\x08turnover\x18\x03 \x01(\x01\x12\x16\n\x0eunderlyingcode\x18\x04 \x01(\x0c\x12\x1d\n\x03\x62id\x18\x05 \x03(\x0b\x32\x10.mdsquote.BSNode\x12\x1d\n\x03\x61sk\x18\x06 \x03(\x0b\x32\x10.mdsquote.BSNode\x12\x15\n\ropen_interest\x18\x07 \x01(\x01\x12\x11\n\tset_price\x18\x08 \x01(\x01\x12\x0f\n\x07voclass\x18\t \x01(\x05\x12\x19\n\x11upper_limit_price\x18\n \x01(\x01\x12\x19\n\x11lower_limit_price\x18\x0b \x01(\x01\x12\x19\n\x11pre_open_interest\x18\x0c \x01(\x01\x12\x0e\n\x06\x65xcode\x18\r \x01(\x0c\x62\x06proto3')
)




_BSNODE = _descriptor.Descriptor(
  name='BSNode',
  full_name='mdsquote.BSNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='mdsquote.BSNode.price', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume', full_name='mdsquote.BSNode.volume', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=73,
)


_BASETICKDATA = _descriptor.Descriptor(
  name='BaseTickData',
  full_name='mdsquote.BaseTickData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='mdsquote.BaseTickData.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='mdsquote.BaseTickData.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='mdsquote.BaseTickData.name', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='mdsquote.BaseTickData.time', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_close_price', full_name='mdsquote.BaseTickData.pre_close_price', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_price', full_name='mdsquote.BaseTickData.open_price', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='high_price', full_name='mdsquote.BaseTickData.high_price', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='low_price', full_name='mdsquote.BaseTickData.low_price', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_price', full_name='mdsquote.BaseTickData.last_price', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=257,
)


_STOCKTICKDATA = _descriptor.Descriptor(
  name='StockTickData',
  full_name='mdsquote.StockTickData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='mdsquote.StockTickData.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume', full_name='mdsquote.StockTickData.volume', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='turnover', full_name='mdsquote.StockTickData.turnover', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bid', full_name='mdsquote.StockTickData.bid', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ask', full_name='mdsquote.StockTickData.ask', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volmount', full_name='mdsquote.StockTickData.volmount', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volclass', full_name='mdsquote.StockTickData.volclass', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outvol', full_name='mdsquote.StockTickData.outvol', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invol', full_name='mdsquote.StockTickData.invol', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lof', full_name='mdsquote.StockTickData.lof', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upper_limit_price', full_name='mdsquote.StockTickData.upper_limit_price', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lower_limit_price', full_name='mdsquote.StockTickData.lower_limit_price', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ywzt', full_name='mdsquote.StockTickData.ywzt', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='after_market_vol', full_name='mdsquote.StockTickData.after_market_vol', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='after_market_volmount', full_name='mdsquote.StockTickData.after_market_volmount', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=260,
  serialized_end=614,
)


_FUTURESTICKDATA = _descriptor.Descriptor(
  name='FuturesTickData',
  full_name='mdsquote.FuturesTickData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='mdsquote.FuturesTickData.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume', full_name='mdsquote.FuturesTickData.volume', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='turnover', full_name='mdsquote.FuturesTickData.turnover', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bid', full_name='mdsquote.FuturesTickData.bid', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ask', full_name='mdsquote.FuturesTickData.ask', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_interest', full_name='mdsquote.FuturesTickData.open_interest', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_set_price', full_name='mdsquote.FuturesTickData.pre_set_price', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_price', full_name='mdsquote.FuturesTickData.set_price', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='voclass', full_name='mdsquote.FuturesTickData.voclass', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upper_limit_price', full_name='mdsquote.FuturesTickData.upper_limit_price', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lower_limit_price', full_name='mdsquote.FuturesTickData.lower_limit_price', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_open_interest', full_name='mdsquote.FuturesTickData.pre_open_interest', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excode', full_name='mdsquote.FuturesTickData.excode', index=12,
      number=13, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='his_hight', full_name='mdsquote.FuturesTickData.his_hight', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='his_low', full_name='mdsquote.FuturesTickData.his_low', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_delta', full_name='mdsquote.FuturesTickData.pre_delta', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cur_delta', full_name='mdsquote.FuturesTickData.cur_delta', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=1021,
)


_NOTIFICATIONTICK = _descriptor.Descriptor(
  name='NotificationTick',
  full_name='mdsquote.NotificationTick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick', full_name='mdsquote.NotificationTick.tick', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1023,
  serialized_end=1082,
)


_CFFEXTICKDATA = _descriptor.Descriptor(
  name='CffexTickData',
  full_name='mdsquote.CffexTickData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='mdsquote.CffexTickData.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume', full_name='mdsquote.CffexTickData.volume', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='turnover', full_name='mdsquote.CffexTickData.turnover', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='underlyingcode', full_name='mdsquote.CffexTickData.underlyingcode', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bid', full_name='mdsquote.CffexTickData.bid', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ask', full_name='mdsquote.CffexTickData.ask', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_interest', full_name='mdsquote.CffexTickData.open_interest', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_price', full_name='mdsquote.CffexTickData.set_price', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='voclass', full_name='mdsquote.CffexTickData.voclass', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upper_limit_price', full_name='mdsquote.CffexTickData.upper_limit_price', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lower_limit_price', full_name='mdsquote.CffexTickData.lower_limit_price', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_open_interest', full_name='mdsquote.CffexTickData.pre_open_interest', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excode', full_name='mdsquote.CffexTickData.excode', index=12,
      number=13, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1085,
  serialized_end=1414,
)

_STOCKTICKDATA.fields_by_name['base'].message_type = _BASETICKDATA
_STOCKTICKDATA.fields_by_name['bid'].message_type = _BSNODE
_STOCKTICKDATA.fields_by_name['ask'].message_type = _BSNODE
_FUTURESTICKDATA.fields_by_name['base'].message_type = _BASETICKDATA
_FUTURESTICKDATA.fields_by_name['bid'].message_type = _BSNODE
_FUTURESTICKDATA.fields_by_name['ask'].message_type = _BSNODE
_NOTIFICATIONTICK.fields_by_name['tick'].message_type = _FUTURESTICKDATA
_CFFEXTICKDATA.fields_by_name['base'].message_type = _BASETICKDATA
_CFFEXTICKDATA.fields_by_name['bid'].message_type = _BSNODE
_CFFEXTICKDATA.fields_by_name['ask'].message_type = _BSNODE
DESCRIPTOR.message_types_by_name['BSNode'] = _BSNODE
DESCRIPTOR.message_types_by_name['BaseTickData'] = _BASETICKDATA
DESCRIPTOR.message_types_by_name['StockTickData'] = _STOCKTICKDATA
DESCRIPTOR.message_types_by_name['FuturesTickData'] = _FUTURESTICKDATA
DESCRIPTOR.message_types_by_name['NotificationTick'] = _NOTIFICATIONTICK
DESCRIPTOR.message_types_by_name['CffexTickData'] = _CFFEXTICKDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BSNode = _reflection.GeneratedProtocolMessageType('BSNode', (_message.Message,), {
  'DESCRIPTOR' : _BSNODE,
  '__module__' : 'quote.mdsquote_pb2'
  # @@protoc_insertion_point(class_scope:mdsquote.BSNode)
  })
_sym_db.RegisterMessage(BSNode)

BaseTickData = _reflection.GeneratedProtocolMessageType('BaseTickData', (_message.Message,), {
  'DESCRIPTOR' : _BASETICKDATA,
  '__module__' : 'quote.mdsquote_pb2'
  # @@protoc_insertion_point(class_scope:mdsquote.BaseTickData)
  })
_sym_db.RegisterMessage(BaseTickData)

StockTickData = _reflection.GeneratedProtocolMessageType('StockTickData', (_message.Message,), {
  'DESCRIPTOR' : _STOCKTICKDATA,
  '__module__' : 'quote.mdsquote_pb2'
  # @@protoc_insertion_point(class_scope:mdsquote.StockTickData)
  })
_sym_db.RegisterMessage(StockTickData)

FuturesTickData = _reflection.GeneratedProtocolMessageType('FuturesTickData', (_message.Message,), {
  'DESCRIPTOR' : _FUTURESTICKDATA,
  '__module__' : 'quote.mdsquote_pb2'
  # @@protoc_insertion_point(class_scope:mdsquote.FuturesTickData)
  })
_sym_db.RegisterMessage(FuturesTickData)

NotificationTick = _reflection.GeneratedProtocolMessageType('NotificationTick', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONTICK,
  '__module__' : 'quote.mdsquote_pb2'
  # @@protoc_insertion_point(class_scope:mdsquote.NotificationTick)
  })
_sym_db.RegisterMessage(NotificationTick)

CffexTickData = _reflection.GeneratedProtocolMessageType('CffexTickData', (_message.Message,), {
  'DESCRIPTOR' : _CFFEXTICKDATA,
  '__module__' : 'quote.mdsquote_pb2'
  # @@protoc_insertion_point(class_scope:mdsquote.CffexTickData)
  })
_sym_db.RegisterMessage(CffexTickData)


# @@protoc_insertion_point(module_scope)



# pyfst - fst client(python)

import os
import sys

rfsdk_root_path = os.path.dirname(__file__)
if rfsdk_root_path not in sys.path:
    sys.path.append(rfsdk_root_path)

pyant_path = os.path.join(rfsdk_root_path, 'pyant')
if pyant_path not in sys.path:
    sys.path.append(pyant_path)

protocol_path = os.path.join(rfsdk_root_path, 'protocol')
if protocol_path not in sys.path:
    sys.path.append(protocol_path)

__version__ = '0.1.0'
